@@ -1,6 +1,8 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, List, Optional
+from __future__ import annotations
+
+from typing import Any
 from ocp_resources.resource import NamespacedResource
 
 
@@ -13,19 +15,19 @@ class Machine(NamespacedResource):
 
     def __init__(
         self,
-        lifecycle_hooks: Optional[Dict[str, Any]] = None,
-        metadata: Optional[Dict[str, Any]] = None,
-        provider_id: Optional[str] = "",
-        provider_spec: Optional[Dict[str, Any]] = None,
-        taints: Optional[List[Any]] = None,
+        lifecycle_hooks: dict[str, Any] | None = None,
+        metadata: dict[str, Any] | None = None,
+        provider_id: str | None = None,
+        provider_spec: dict[str, Any] | None = None,
+        taints: list[Any] | None = None,
         **kwargs: Any,
     ) -> None:
         """
         Args:
-            lifecycle_hooks (Dict[str, Any]): LifecycleHooks allow users to pause operations on the machine at
+            lifecycle_hooks (dict[str, Any]): LifecycleHooks allow users to pause operations on the machine at
               certain predefined points within the machine lifecycle.
 
-            metadata (Dict[str, Any]): ObjectMeta will autopopulate the Node created. Use this to indicate
+            metadata (dict[str, Any]): ObjectMeta will autopopulate the Node created. Use this to indicate
               what labels, annotations, name prefix, etc., should be used when
               creating the Node.
 
@@ -45,10 +47,10 @@ class Machine(NamespacedResource):
               autoscaler that will be interfacing with cluster-api as generic
               provider.
 
-            provider_spec (Dict[str, Any]): ProviderSpec details Provider-specific configuration to use during
+            provider_spec (dict[str, Any]): ProviderSpec details Provider-specific configuration to use during
               node creation.
 
-            taints (List[Any]): The list of the taints to be applied to the corresponding Node in
+            taints (list[Any]): The list of the taints to be applied to the corresponding Node in
               additive manner. This list will not overwrite any other taints
               added to the Node on an ongoing basis by other entities. These
               taints should be actively reconciled e.g. if you ask the machine
